@@ -4,18 +4,28 @@
 # @Email   : josephchenhk@gmail.com
 # @FileName: deal.py
 # @Software: PyCharm
+
+"""
+Copyright (C) 2020 Joseph Chen - All Rights Reserved
+You may use, distribute and modify this code under the
+terms of the JXW license, which unfortunately won't be
+written for another century.
+
+You should have received a copy of the JXW license with
+this file. If not, please write to: josephchenhk@gmail.com
+"""
+
 from dataclasses import dataclass
 from datetime import datetime
 
 from qtrader.core.constants import Direction, Offset, OrderType
-from qtrader.core.security import Stock
+from qtrader.core.security import Security
+
 
 @dataclass
 class Deal:
-    """
-    成交
-    """
-    security: Stock
+    """Done deal/execution"""
+    security: Security
     direction: Direction
     offset: Offset
     order_type: OrderType
