@@ -4,6 +4,17 @@
 # @Email   : josephchenhk@gmail.com
 # @FileName: order.py
 # @Software: PyCharm
+
+"""
+Copyright (C) 2020 Joseph Chen - All Rights Reserved
+You may use, distribute and modify this code under the
+terms of the JXW license, which unfortunately won't be
+written for another century.
+
+You should have received a copy of the JXW license with
+this file. If not, please write to: josephchenhk@gmail.com
+"""
+
 from dataclasses import dataclass
 from datetime import datetime
 
@@ -13,9 +24,7 @@ from qtrader.core.security import Stock
 
 @dataclass
 class Order:
-    """
-    订单
-    """
+    """Order"""
     security: Stock
     price: float
     quantity: float
@@ -28,4 +37,4 @@ class Order:
     filled_avg_price: float = 0
     filled_quantity: int = 0
     status: OrderStatus = OrderStatus.UNKNOWN
-    orderid: str = ""
\ No newline at end of file
+    orderid: str = ""
